DisplayVtbl

Struct DisplayVtbl 

pub struct DisplayVtbl<'cglue_a, CGlueC: 'cglue_a + CGlueObjBase> { /* private fields */ }
CGlue vtable for trait Display.

This virtual function table contains ABI-safe interface for the given trait.

Implementations

Source

impl<'cglue_a, CGlueC: CGlueObjBase> DisplayVtbl<'cglue_a, CGlueC>

pub fn fmt( &self, ) -> unsafe extern "C" fn(cont: &CGlueC, f_out: &mut WriteMut<'_>) -> i32

Getter for fmt.

Note that this function is wrapped into unsafe, because if already were is an opaque one, it would allow to invoke undefined behaviour.